/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package top.continew.admin.controller.business;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.enums.ParameterIn;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.AllArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import top.continew.admin.business.model.entity.TgUser;
import top.continew.admin.business.model.query.TgUserQuery;
import top.continew.admin.business.model.query.TgUserTeamQuery;
import top.continew.admin.business.model.req.TgUserReq;
import top.continew.admin.business.service.ITgUserService;
import top.continew.starter.extension.crud.model.resp.BasePageResp;

import java.util.List;

@RestController()
@RequestMapping("/tgUser")
@AllArgsConstructor
@Tag(name = "tg用户管理 API")
public class TgUserController {
    private final ITgUserService userService;

    @RequestMapping("/getTgUserList")
    @Operation(summary = "获取tg用户列表", description = "获取tg用户列表")
    public BasePageResp<TgUser> getTgUserList(TgUserQuery query) {
        return userService.pageQuery(query);
    }

    @Operation(summary = "修改数据", description = "修改数据")
    @Parameter(name = "id", description = "ID", example = "1", in = ParameterIn.PATH)
    @PutMapping({"/{id}"})
    //@Validated({CrudValidationGroup.Update.class})
    public void update(@RequestBody TgUserReq req, @PathVariable("id") Long id) {
        this.userService.updateTgUserInfo(id, req);
    }

    @Operation(summary = "禁用账号", description = "禁用账号")
    @GetMapping("/disable/{ids}")
    @Parameter(name = "ids", description = "ids", example = "1,2,3,4", in = ParameterIn.PATH)
    public void disableTgUser(@PathVariable("ids") List<Long> ids) {
        userService.disableTgUserByIds(ids);
    }

    @Operation(summary = "获取团队成员列表", description = "获取团队成员列表")
    @GetMapping("/getMyTeamUserList")
    public BasePageResp<TgUser> getMyTeamUserList(@Validated TgUserTeamQuery query) {
        return userService.getMyTeamUserListByType(query);
    }
}
